Module: BhaktScript::Bhakt
- Defined in:
- lib/bhakt_script/bhakt.rb
Constant Summary collapse
- QUOTES =
[ 'Fix this or goto pakisthan', 'How dare you make this error when soldiers are struggling in the border !', 'These bloody sickulars always making problems', 'The person who made this error must be a congi/aaptard', 'Modi will fix this !' ]
Instance Method Summary collapse
Instance Method Details
#message(*args) ⇒ Object
10 11 12 |
# File 'lib/bhakt_script/bhakt.rb', line 10 def *args QUOTES.sample end |